package web.service;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import persistence.model.Assunto;
import persistence.model.Noticia;
import persistence.model.Usuario;

public class NoticiaServiceImpl implements NoticiaService {

	private static List<NoticiaListener> listeners = new ArrayList<NoticiaListener>();
	
	public void addNoticia(Noticia noticia) {
		try {
			PreparedStatement ps = getConnection()
					.prepareStatement("insert into noticia (id_usuario, id_assunto, titulo, texto) values (?, ?, ?, ?)");
			
			ps.setInt(1, noticia.getUsuario().getIdUsuario());
			ps.setLong(2, noticia.getAssunto().getAssuntoId());
			ps.setString(3, noticia.getTitulo());
			ps.setString(4, noticia.getTexto());
			
			ps.execute();	
			
			notifyListeners(noticia);
			
		} catch (SQLException e) {			
			throw new RuntimeException(e);
		}						

	}

	private void notifyListeners(Noticia noticia) {
		for(NoticiaListener listener : listeners) {
			if(listener != null) {
				listener.receberNovaNoticia(noticia);
				synchronized (listener) {
					listener.notifyAll();
				}
			}
		}		
	}

	public Noticia findByID(long id) {
		
		try {
			PreparedStatement ps = getConnection().prepareStatement("select * from noticia where id = ?");			
			ps.setLong(1, id);
			
			ResultSet rs = ps.executeQuery();
			
			UsuarioService usuarioService = new UsuarioServiceImpl();
			AssuntoService assuntoService = new AssuntoServiceImpl();
			
			rs.next();
			
			Noticia noticia = new Noticia();
			
			noticia.setIdNoticia(rs.getLong(1));
			long idUsuario = rs.getLong(2);				
			Usuario usuario = usuarioService.findById(idUsuario);
			noticia.setUsuario(usuario);
			
			long idAssunto = rs.getLong(3);
			Assunto assunto = assuntoService.findByID(idAssunto);
			noticia.setAssunto(assunto);			
			noticia.setTitulo(rs.getString(4));
			noticia.setTexto(rs.getString(5));		
			
			return noticia;
			
		} catch (SQLException e) {
			throw new RuntimeException(e);
		}
		
	}
	
	public List<Noticia> getAllNoticias() {
		List<Noticia> noticias = new ArrayList<Noticia>();
		
		try {
			PreparedStatement ps = getConnection().prepareStatement("select * from noticia");				
			
			ResultSet rs = ps.executeQuery();
			
			UsuarioService usuarioService = new UsuarioServiceImpl();
			AssuntoService assuntoService = new AssuntoServiceImpl();
			
			while (rs.next()) {

				Noticia noticia = new Noticia();				
				noticia.setIdNoticia(rs.getLong(1));	
				
				long idUsuario = rs.getLong(2);				
				Usuario usuario = usuarioService.findById(idUsuario);
				noticia.setUsuario(usuario);
				
				long idAssunto = rs.getLong(3);
				Assunto assunto = assuntoService.findByID(idAssunto);
				noticia.setAssunto(assunto);
				
				noticia.setTitulo(rs.getString(4));
				noticia.setTexto(rs.getString(5));
				
				noticias.add(noticia);

			}
			return noticias;
			
		} catch (SQLException e) {
			throw new RuntimeException(e);
		}		
		
	}

	public List<Noticia> getAllNoticiasByAssunto(Long assuntoId) {
		List<Noticia> noticias = new ArrayList<Noticia>();
		
		try {
			PreparedStatement ps = getConnection().prepareStatement("select * from noticia where id_assunto = ?");				
			ps.setLong(1, assuntoId);
			
			ResultSet rs = ps.executeQuery();
			
			UsuarioService usuarioService = new UsuarioServiceImpl();
			AssuntoService assuntoService = new AssuntoServiceImpl();
			
			while (rs.next()) {

				Noticia noticia = new Noticia();				
				noticia.setIdNoticia(rs.getLong(1));	
				
				long idUsuario = rs.getLong(2);				
				Usuario usuario = usuarioService.findById(idUsuario);
				noticia.setUsuario(usuario);
				
				long idAssunto = rs.getLong(3);
				Assunto assunto = assuntoService.findByID(idAssunto);
				noticia.setAssunto(assunto);
				
				noticia.setTitulo(rs.getString(4));
				noticia.setTexto(rs.getString(5));
				
				noticias.add(noticia);

			}
			return noticias;
			
		} catch (SQLException e) {
			throw new RuntimeException(e);
		}
	}
	
	private Connection getConnection() {
		return ConnectionFactory.getInstance().getConnection();
	}

	public void addListener(NoticiaListener noticiaListener) {
		listeners.add(noticiaListener);		
	}

	public void removeListener(NoticiaListener noticiaListener) {
		listeners.remove(noticiaListener);		
	}

}
