package web.servlet;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.RequestDispatcher;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import persistence.dao.DAOFactory;
import persistence.model.Avaliacao;
import persistence.model.Noticia;
import persistence.model.Usuario;
import util.exception.ServiceException;
import web.service.AvaliacaoService;
import web.service.NoticiaService;

/**
 * Servlet implementation class ListNoticias
 */
public class AdicionaAvaliacao extends HttpServlet {
	private static final long serialVersionUID = 1L;
	private List<String> errors; 
	private AvaliacaoService avaliacaoService;
	private NoticiaService noticiaService;
	
    /**
     * @see HttpServlet#HttpServlet()
     */
    public AdicionaAvaliacao() {
        super();
    }

	/**
	 * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doGet(HttpServletRequest request, HttpServletResponse response) {
		try {
			doAction(request, response);
		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}

	/**
	 * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doPost(HttpServletRequest request, HttpServletResponse response) {
		try {
			doAction(request, response);
		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}
	
	protected void doAction(HttpServletRequest request, HttpServletResponse response) throws ServiceException {
		String avaliacaoUsuario = request.getParameter("avaliacao");
		String noticiaId = request.getParameter("noticiaId");
		Usuario usuario = null;
		
		try {
			avaliacaoService = DAOFactory.getInstance().getDao(AvaliacaoService.class);
			noticiaService = DAOFactory.getInstance().getDao(NoticiaService.class);
			errors = new ArrayList<String>();
			
			validaUsuario(avaliacaoUsuario);

			if ( errors.size() == 0 ) {
				usuario = (Usuario) request.getSession().getAttribute("Usuario");
				
				if (usuario != null) {
					Noticia noticia = noticiaService.findByID(Long.parseLong(noticiaId));

					if (!avaliacaoService.avaliacaoExists(usuario.getIdUsuario(), noticia.getIdNoticia())) {
						Avaliacao avaliacao;

						if(avaliacaoUsuario.equals("positiva")) {					
							avaliacao = new Avaliacao(noticia, usuario, 1);
						}
						else {
							avaliacao = new Avaliacao(noticia, usuario, -1);
						}

						avaliacaoService.addAvaliacao(avaliacao);
						RequestDispatcher dispatcher = request.getRequestDispatcher("jsp/confirmaAvaliacao.jsp");
						dispatcher.forward(request, response);
					}
					else {
						errors.add("Voc j avaliou esta notcia.");
						request.setAttribute("errors", errors);
						request.setAttribute("avaliated", "true");
						RequestDispatcher dispatcher = request.getRequestDispatcher("leNoticia?noticiaId=" + noticiaId);
						dispatcher.forward(request, response);
					}
				}
				else {
					errors.add("Usurio no autenticado");
					request.setAttribute("errors", errors);
					RequestDispatcher dispatcher = request.getRequestDispatcher("index.jsp");
					dispatcher.forward(request, response);
				}
			}
			else {
				request.setAttribute("errors", errors);
				RequestDispatcher dispatcher = request.getRequestDispatcher("leNoticia?noticiaId=" + noticiaId);
				dispatcher.forward(request, response);
			}
		}
		catch (Exception e) {
			throw new ServiceException(e);
		}
	}

	private void validaUsuario(String avaliacao) {				
		if (avaliacao == null) {
			errors.add("Avaliao no preenchida.");
		}	
	}
}
