package web.servlet;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.RequestDispatcher;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import persistence.dao.DAOFactory;
import persistence.model.Assunto;
import persistence.model.Noticia;
import persistence.model.Usuario;
import util.exception.ServiceException;
import web.service.AssuntoService;
import web.service.NoticiaService;

/**
 * Servlet implementation class ListNoticias
 */
public class AdicionaNoticia extends HttpServlet {
	private static final long serialVersionUID = 1L;
	private List<String> errors;  
	private NoticiaService noticiaService;
	private AssuntoService assuntoService;
	/**
	 * @see HttpServlet#HttpServlet()
	 */
	public AdicionaNoticia() {
		super();
	}

	/**
	 * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doGet(HttpServletRequest request, HttpServletResponse response) {
		try {
			doAction(request, response);
		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}

	/**
	 * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doPost(HttpServletRequest request, HttpServletResponse response) {
		try {
			doAction(request, response);
		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}

	protected void doAction(HttpServletRequest request, HttpServletResponse response) throws ServiceException {
		String titulo = request.getParameter("textTitulo");
		String texto = request.getParameter("textTexto");
		Long assuntoId = Long.parseLong(request.getParameter("assuntoId"));
		Usuario usuario = null;

		try {
			noticiaService = DAOFactory.getInstance().getDao(NoticiaService.class);
			assuntoService = DAOFactory.getInstance().getDao(AssuntoService.class);
			errors = new ArrayList<String>();
			validaUsuario(titulo, texto);

			if ( errors.size() == 0 ) {
				usuario = (Usuario) request.getSession().getAttribute("Usuario");
				
				if (usuario != null) {
					Assunto assunto = assuntoService.findByID(assuntoId);
					Noticia noticia = new Noticia(usuario, assunto, titulo, texto);
					noticiaService.addNoticia(noticia);
					RequestDispatcher dispatcher = request.getRequestDispatcher("jsp/confirmaNoticia.jsp");
					dispatcher.forward(request, response);
				}
				else {
					errors.add("Usurio no autenticado");
					request.setAttribute("errors", errors);
					RequestDispatcher dispatcher = request.getRequestDispatcher("index.jsp");
					dispatcher.forward(request, response);
				}
			}
			else {
				request.setAttribute("errors", errors);
				RequestDispatcher dispatcher = request.getRequestDispatcher("jsp/adicionaNoticia.jsp");
				dispatcher.forward(request, response);
			}
		}
		catch (Exception e) {
			throw new ServiceException(e);
		}
	}

	private void validaUsuario(String titulo, String texto) {				
		if ("".equals(titulo)) {
			errors.add("Ttulo vazio.");
		}	
		if ("".equals(texto)) {
			errors.add("Texto vazio.");
		}
	}
}
