package web.servlet;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.RequestDispatcher;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import persistence.dao.DAOFactory;
import persistence.model.Usuario;
import util.exception.ServiceException;
import web.service.UsuarioService;

/**
 * Servlet implementation class ListNoticias
 */
public class AdicionaUsuario extends HttpServlet {
	private static final long serialVersionUID = 1L;
	private List<String> errors;
	private UsuarioService usuarioService;   
	/**
	 * @see HttpServlet#HttpServlet()
	 */
	public AdicionaUsuario() {
		super();
	}

	/**
	 * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doGet(HttpServletRequest request, HttpServletResponse response) {
		try {
			doAction(request, response);
		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}

	/**
	 * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doPost(HttpServletRequest request, HttpServletResponse response) {
		try {
			doAction(request, response);
		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}

	protected void doAction(HttpServletRequest request, HttpServletResponse response) throws ServiceException {	
		String login = request.getParameter("textLogin");
		String senha = request.getParameter("textPassword");
		String email = request.getParameter("textEmail");

		try {
			usuarioService = DAOFactory.getInstance().getDao(UsuarioService.class);
			errors = new ArrayList<String>();

			validaUsuario(login, senha, email);

			if ( errors.size() == 0 ) {
				Usuario usuario = new Usuario(login, senha, email);
				usuarioService.addUsuario(usuario);
				RequestDispatcher dispatcher = request.getRequestDispatcher("jsp/confirmaUsuario.jsp");
				dispatcher.forward(request, response);
			}
			else {
				request.setAttribute("errors", errors);
				RequestDispatcher dispatcher = request.getRequestDispatcher("jsp/adicionaUsuario.jsp");
				dispatcher.forward(request, response);
			}
		}
		catch (Exception e) {
			throw new ServiceException(e);
		}
	}

	private void validaUsuario(String login, String senha, String email) {				
		if ("".equals(login)) {
			errors.add("Login vazio.");
		}	
		else if(usuarioService.findByLogin(login) != null) 
		{
			errors.add("Login j existe.");
		}	
		if ("".equals(senha)) {
			errors.add("Senha vazia.");
		}
		if ("".equals(email)) {
			errors.add("E-mail vazio.");
		}
	}

}
