package web.servlet;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.RequestDispatcher;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import persistence.dao.DAOFactory;
import persistence.model.Usuario;
import util.exception.ServiceException;
import web.service.NoticiaService;

/**
 * Servlet implementation class ListNoticias
 */
public class ListaNoticias extends HttpServlet {
	private static final long serialVersionUID = 1L;
	private List<String> errors;
	private NoticiaService noticiaService;


	/**
	 * @see HttpServlet#HttpServlet()
	 */
	public ListaNoticias() {
		super();
	}

	/**
	 * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doGet(HttpServletRequest request, HttpServletResponse response) {
		try {
			doAction(request, response);
		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}

	/**
	 * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doPost(HttpServletRequest request, HttpServletResponse response) {
		try {
			doAction(request, response);
		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}

	protected void doAction(HttpServletRequest request, HttpServletResponse response) throws ServiceException {
		Usuario usuario = (Usuario) request.getSession().getAttribute("Usuario");
		errors = new ArrayList<String>();

		try {
			if (usuario != null) {
				noticiaService = DAOFactory.getInstance().getDao(NoticiaService.class);
				String assuntoId = request.getParameter("assuntoId");
				if(assuntoId != null) {
					request.setAttribute("noticias", noticiaService.getAllNoticiasByAssunto(Long.parseLong(assuntoId)));
				}
				else {
					request.setAttribute("noticias", noticiaService.getAllNoticias());
				}

				RequestDispatcher dispatcher = request.getRequestDispatcher("jsp/listaNoticias.jsp");
				dispatcher.forward(request, response);
			}
			else {
				errors.add("Usurio no autenticado");
				request.setAttribute("errors", errors);
				RequestDispatcher dispatcher = request.getRequestDispatcher("index.jsp");
				dispatcher.forward(request, response);
			}
		}	
		catch (Exception e) {
			throw new ServiceException(e);
		}
	}
}
