package web.servlet;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.RequestDispatcher;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import persistence.dao.DAOFactory;
import persistence.model.Usuario;
import util.exception.ServiceException;
import web.service.NoticiaService;
import web.service.NoticiaServiceImpl;
import web.service.UsuarioService;

/**
 * Servlet implementation class ListNoticias
 */
public class Login extends HttpServlet {
	private static final long serialVersionUID = 1L;
	private List<String> errors;
	private Usuario usuario;
	private NoticiaService noticiaService;
	private UsuarioService usuarioService;

	/**
	 * @see HttpServlet#HttpServlet()
	 */
	public Login() {
		super();
	}

	/**
	 * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doGet(HttpServletRequest request, HttpServletResponse response) {
		try {
			doAction(request, response);
		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}

	/**
	 * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doPost(HttpServletRequest request, HttpServletResponse response) {
		try {
			doAction(request, response);
		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}

	protected void doAction(HttpServletRequest request, HttpServletResponse response) throws ServiceException {
		String login = request.getParameter("textLogin");
		String senha = request.getParameter("textPassword");
		
		try {
			noticiaService = DAOFactory.getInstance().getDao(NoticiaService.class);
			usuarioService = DAOFactory.getInstance().getDao(UsuarioService.class);
			
			errors = new ArrayList<String>();
			validaUsuario(login, senha);

			if ( errors.size() == 0 ) {
				noticiaService = new NoticiaServiceImpl();
				request.setAttribute("noticias", noticiaService.getAllNoticias());
				request.getSession().setAttribute("Usuario", usuario);

				RequestDispatcher dispatcher = request.getRequestDispatcher("jsp/listaNoticias.jsp");
				dispatcher.forward(request, response);
			}
			else {
				request.setAttribute("errors", errors);
				RequestDispatcher dispatcher = request.getRequestDispatcher("index.jsp");
				dispatcher.forward(request, response);
			}
		}
		catch (Exception e) {
			throw new ServiceException(e);
		}
	}

	private void validaUsuario(String login, String senha) {				
		if ("".equals(login)) {
			errors.add("Login vazio.");
		}	
		if ("".equals(senha)) {
			errors.add("Senha vazia.");
		}
		
		usuario = usuarioService.findByLoginAndSenha(login, senha);
		if (usuario == null && errors.size() == 0) {
			errors.add("Usurio ou senha invlido.");
		}
	}	
}
