package web.servlet;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import persistence.dao.DAOFactory;
import persistence.model.Noticia;
import util.exception.ServiceException;
import web.service.NoticiaListener;
import web.service.NoticiaService;

/**
 * Servlet implementation class VerificaNovasNoticias
 */
public class VerificaNovasNoticias extends HttpServlet implements NoticiaListener{
	private static final long serialVersionUID = 1L;
	private String delimitador = "delimitador";
	private volatile Noticia ultimaNoticia = null;
	private NoticiaService noticiaService;
	
	/**
	 * @see HttpServlet#HttpServlet()
	 */
	public VerificaNovasNoticias() {
		super();
		
	}
	
	@Override
	public void destroy() {
		super.destroy();
		
		if(noticiaService != null) noticiaService.removeListener(this);
	}

	/**
	 * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doGet(HttpServletRequest request, HttpServletResponse response) {
		try {
			doAction(request, response);
		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}

	/**
	 * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doPost(HttpServletRequest request, HttpServletResponse response) {
		try {
			doAction(request, response);
		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}

	protected void doAction(HttpServletRequest request,	HttpServletResponse response) throws ServiceException {
		try {
			iniciaMultipartResponse(response);

			noticiaService = DAOFactory.getInstance().getDao(NoticiaService.class);
			noticiaService.addListener(this);

			while (true) {
				synchronized (this) {
					try {
						wait();

						if (ultimaNoticia != null) {
							doComet(ultimaNoticia, response);							
						}
					} catch (InterruptedException e) {
						e.printStackTrace();
					}
				}
			}
		} catch (IOException e) {
			throw new ServiceException(e);
		}
	}

	private void doComet(Noticia noticia, HttpServletResponse response) throws IOException {
		PrintWriter writer = response.getWriter();
		writer.write("Content-type: text/x-json\n\n");
		writer.write("{\n");
		writer.write("\"titulo\":\"" + noticia.getTitulo()  + "\",\n");
		writer.write("\"texto\":\"" + noticia.getTexto() +"\",\n");
		writer.write("\"nome\":\"" + noticia.getUsuario().getLogin() + "\",\n");
		writer.write("\"id\":\"" + noticia.getIdNoticia() + "\"\n");
		writer.write("}\n");
		response.flushBuffer();
		writer.println("--" + delimitador);
		response.flushBuffer();
	}
	
	private void iniciaMultipartResponse(HttpServletResponse resp) throws IOException {
		resp.setHeader("Content-type", "multipart/x-mixed-replace;boundary=\"" + delimitador + "\"");		
		resp.getWriter().write("--" + delimitador + "\n");
	}

	public void receberNovaNoticia(Noticia noticia) {
		ultimaNoticia = noticia;		
	}

}
